This crate contains kube-rs compatible bindings for Kubernetes custom resources for the virt.virtink.smartx.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
virt.virtink.smartx.com/v1alpha1
VirtualMachineMigrationVirtualMachine